#pragma once

#include <tchar.h>
#include "tipconst.h"

namespace tipcommon
{
	struct Owner
	{
		enum Type
		{
			Installer,
			Updater,
		};
	};

	struct Entry
	{
		enum Type
		{
			MainView,
			AlarmView,
			RetryNormalInstall,
			PromotionSilentInstall
		};
	};

	class IStatManager
	{
	public:
		IStatManager() {}
		virtual ~IStatManager() {}
		BOOL SendInstallLog(LPCTSTR guid);
		BOOL SendUpdateLog(LPCTSTR guid);
		BOOL SendRemoveLog(LPCTSTR guid);
		BOOL SendInstallUpdaterLog();
		BOOL SendStartPageLog();
		BOOL SendDefaultSearchLog();
		BOOL SendHideOtherToolbarLog();
		virtual Owner::Type GetOwner() = 0;
		virtual LPCTSTR GetStatUrl() = 0;
		virtual Entry::Type GetEntry() = 0;
		virtual void SetEntry(Entry::Type entry) = 0;
	private:
		CString MakeBaseLog();
	};


	class InstallerStatManager : public IStatManager
	{
	public:
		InstallerStatManager(LPCTSTR url);
		virtual ~InstallerStatManager() {}

		Owner::Type GetOwner() { return Owner::Installer; }
		Entry::Type GetEntry() { return Entry::MainView; }
		void SetEntry(Entry::Type entry = Entry::MainView) {}
		LPCTSTR GetStatUrl() { return m_Url; }

	private:
		InstallerStatManager() {}
		TCHAR m_Url[tipbase::MAXURL];
	};

	class UpdaterStatManager : public IStatManager
	{
	public:
		UpdaterStatManager(LPCTSTR url);
		virtual ~UpdaterStatManager() {}

		Owner::Type GetOwner() { return Owner::Updater; }
		Entry::Type GetEntry() { return m_Entry; }
		void SetEntry(Entry::Type entry = Entry::MainView) 
		{ 
			m_Entry = entry; 
		}
		LPCTSTR GetStatUrl() { return m_Url; }


	private:
		UpdaterStatManager() {}
		TCHAR m_Url[tipbase::MAXURL];
		Entry::Type m_Entry;
	};

};